==> open-next-cdk-0.0.6-sources.jar: io/dataspray/opennextcdk/NextjsDistributionCdkProps.java <==
package io.dataspray.opennextcdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-07-30T03:46:44.249Z")
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.NextjsDistributionCdkProps")
@software.amazon.jsii.Jsii.Proxy(NextjsDistributionCdkProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NextjsDistributionCdkProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Pass in a value to override the default settings this construct uses to create the CloudFront `Distribution` internally.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.DistributionProps getDistribution() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NextjsDistributionCdkProps> {
        software.amazon.awscdk.services.cloudfront.DistributionProps distribution;

        /**
         * Sets the value of {@link NextjsDistributionCdkProps#getDistribution}
         * @param distribution Pass in a value to override the default settings this construct uses to create the CloudFront `Distribution` internally.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder distribution(software.amazon.awscdk.services.cloudfront.DistributionProps distribution) {
            this.distribution = distribution;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextjsDistributionCdkProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NextjsDistributionCdkProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextjsDistributionCdkProps {
        private final software.amazon.awscdk.services.cloudfront.DistributionProps distribution;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.distribution = software.amazon.jsii.Kernel.get(this, "distribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.DistributionProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.distribution = builder.distribution;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.DistributionProps getDistribution() {
            return this.distribution;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDistribution() != null) {
                data.set("distribution", om.valueToTree(this.getDistribution()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("open-next-cdk.NextjsDistributionCdkProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextjsDistributionCdkProps.Jsii$Proxy that = (NextjsDistributionCdkProps.Jsii$Proxy) o;

            return this.distribution != null ? this.distribution.equals(that.distribution) : that.distribution == null;
        }

        @Override
        public final int hashCode() {
            int result = this.distribution != null ? this.distribution.hashCode() : 0;
            return result;
        }
    }
}

==> open-next-cdk-0.0.9-sources.jar: io/dataspray/opennextcdk/NextjsDistributionCdkProps.java <==
package io.dataspray.opennextcdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.86.0 (build bc5c93a)", date = "2023-09-25T15:41:32.936Z")
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.NextjsDistributionCdkProps")
@software.amazon.jsii.Jsii.Proxy(NextjsDistributionCdkProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NextjsDistributionCdkProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Pass in a value to override the default settings this construct uses to create the CloudFront <code>Distribution</code> internally.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.DistributionProps getDistribution() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NextjsDistributionCdkProps> {
        software.amazon.awscdk.services.cloudfront.DistributionProps distribution;

        /**
         * Sets the value of {@link NextjsDistributionCdkProps#getDistribution}
         * @param distribution Pass in a value to override the default settings this construct uses to create the CloudFront <code>Distribution</code> internally.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder distribution(software.amazon.awscdk.services.cloudfront.DistributionProps distribution) {
            this.distribution = distribution;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextjsDistributionCdkProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NextjsDistributionCdkProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextjsDistributionCdkProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextjsDistributionCdkProps {
        private final software.amazon.awscdk.services.cloudfront.DistributionProps distribution;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.distribution = software.amazon.jsii.Kernel.get(this, "distribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.DistributionProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.distribution = builder.distribution;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.DistributionProps getDistribution() {
            return this.distribution;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDistribution() != null) {
                data.set("distribution", om.valueToTree(this.getDistribution()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("open-next-cdk.NextjsDistributionCdkProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextjsDistributionCdkProps.Jsii$Proxy that = (NextjsDistributionCdkProps.Jsii$Proxy) o;

            return this.distribution != null ? this.distribution.equals(that.distribution) : that.distribution == null;
        }

        @Override
        public final int hashCode() {
            int result = this.distribution != null ? this.distribution.hashCode() : 0;
            return result;
        }
    }
}
